﻿using Microsoft.AspNetCore.Http;
using NetworkResurrector.Api.Domain.Abstractions;
using System;
using System.Linq;
using System.Security.Claims;

namespace NetworkResurrector.Api.Services
{
    public class UserService : IUserService
    {
        private readonly IHttpContextAccessor _httpAccessor;

        public UserService(IHttpContextAccessor httpAccessor)
        {
            _httpAccessor = httpAccessor;
        }

        public bool UserIsLoggedIn => _httpAccessor.HttpContext.User != null;

        public string GetUserId()
        {
            var userId = _httpAccessor.HttpContext.User?.Claims.FirstOrDefault(z => z.Type == ClaimTypes.NameIdentifier)?.Value;

            if (string.IsNullOrEmpty(userId))
                throw new Exception("User id could not be retrieved from claims.");

            return userId;
        }

        public string GetUserName()
        {
            var userName = _httpAccessor.HttpContext.User?.Claims.FirstOrDefault(z => z.Type == ClaimTypes.Name)?.Value;

            if (string.IsNullOrEmpty(userName))
                throw new Exception("User name could not be retrieved from claims.");

            return userName;
        }

        public bool UserIsGuest()
        {
            var userIsGuest = _httpAccessor.HttpContext.User?.Claims.FirstOrDefault(z => z.Type == Netmash.Security.Authentication.Tuitio.Constants.ClaimTypes.IsGuestUser)?.Value;
            return !string.IsNullOrEmpty(userIsGuest) && bool.TrueString == userIsGuest;
        }
    }
}
